#   Copyright (C) 2003 Nicolas Centa
 
#   This program is free software; you can redistribute it and/or
#   modify it under the terms of the GNU General Public License as
#   published by the Free Software Foundation; either version 2 of the
#   License, or (at your option) any later version.
 
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
 
#   You should have received a copy of the GNU General Public License
#   along with this program; if not, write to the Free Software
#   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
#   USA

import ConfigParser

import pygtk
pygtk.require('2.0')
import gtk
import gtk.glade
import gobject

import pyfsconf
import fsdb
import paths

class PyFS_main:
    def __init__(self):
        self.xml = gtk.glade.XML('pyfsmanager.glade','PyFS_main')
        self.connect()
        self.init_config()
        
    def init_config(self):
        cfg = ConfigParser.ConfigParser()
        cfg.read('pyfs.cfg')
        if cfg.has_section('main'):
            self.fspath = cfg.get('main','fspath')
            self.launch()
        else:
            self.fspath = None
            self.conf = pyfsconf.PyFSconf(self.launch)
            self.conf.launch()

    def init_pix(self):
        self.pix_fs = gtk.gdk.pixbuf_new_from_file('pyfs.xpm')
        self.pix_aircraft = gtk.gdk.pixbuf_new_from_file('pyair.xpm')
        self.pix_panel = gtk.gdk.pixbuf_new_from_file('pypanel.xpm')
        self.pix_sound = gtk.gdk.pixbuf_new_from_file('pysound.xpm')
    
    def init_left_view(self):
        left_view = self['left_view']
        left_view.model = gtk.TreeStore(str,gtk.gdk.Pixbuf)
        left_view.set_model(left_view.model)
        left_view.text_renderer = gtk.CellRendererText()
        left_view.pix_renderer = gtk.CellRendererPixbuf()
        left_view.text_column = gtk.TreeViewColumn("Index", left_view.text_renderer, text=0)
        left_view.pix_column = gtk.TreeViewColumn("X", left_view.pix_renderer, pixbuf=1)
        left_view.append_column(left_view.pix_column)
        left_view.append_column(left_view.text_column)
        pix = gtk.gdk.pixbuf_new_from_file('pyfs.xpm')
        left_view.root_iter = left_view.model.insert_before(None,None)
        left_view.child_iter = [left_view.model.insert_before
                                        (left_view.root_iter,None),
                                        left_view.model.insert_before
                                        (left_view.root_iter,None),
                                        left_view.model.insert_before
                                        (left_view.root_iter,None)]
        left_view.model[0][0] = 'Flight Simulator'
        left_view.model[0,0][0] = 'Aircrafts'
        left_view.model[0,1][0] = 'Panels'
        left_view.model[0,2][0] = 'Sounds'
        left_view.model[0][1] = self.pix_fs
        left_view.model[0,0][1] = self.pix_aircraft
        left_view.model[0,1][1] = self.pix_panel
        left_view.model[0,2][1] = self.pix_sound

    def init_right_view(self):
        right_view = self['right_view']
        right_view.model = [None, None, None]
        right_view.text_renderer = gtk.CellRendererText()
        right_view.pix_renderer = gtk.CellRendererPixbuf()
        right_view.text_column = gtk.TreeViewColumn("Name",
                                                    right_view.text_renderer, text=0)
        right_view.pix_column = gtk.TreeViewColumn('', right_view.pix_renderer, pixbuf=2)
        right_view.append_column(right_view.pix_column)
        right_view.append_column(right_view.text_column)
        
    def init_aircraft_model(self):
        model = self['right_view'].model
        model[0] = gtk.ListStore(str,int,gtk.gdk.Pixbuf)
        model[0].child_iter = []
        for i in range(len(self.db[0])):
            model[0].child_iter += [model[0].insert(i)]
            model[0][i][0] = self.db[0][i][1]
            model[0][i][1] = i
            model[0][i][2] = self.pix_aircraft

    def init_panel_model(self):
        right_view = self['right_view']
        model = right_view.model
        model[1] = gtk.ListStore(str,int,gtk.gdk.Pixbuf)
        model[1].child_iter = []
        for i in range(len(self.db[1])):
            model[1].child_iter += [model[1].insert(i)]
            model[1][i][0] = paths.arrange_path(self.db[1][i],32)
            model[1][i][1] = i
            model[1][i][2] = self.pix_panel

    def init_sound_model(self):
        right_view = self['right_view']
        model = right_view.model
        model[2] = gtk.ListStore(str,int,gtk.gdk.Pixbuf)
        model[2].child_iter = []
        for i in range(len(self.db[2])):
            model[2].child_iter += [model[2].insert(i)]
            model[2][i][0] = paths.arrange_path(self.db[2][i],32)
            model[2][i][1] = i
            model[2][i][2] = self.pix_sound

    def write_config(self):
        self.fspath = self.conf.fspath
        cfg = ConfigParser.ConfigParser()
        cfg.add_section('main')
        cfg.set('main','fspath',self.fspath)
        fp = file('pyfs.cfg','w')
        cfg.write(fp)
        fp.close()

    def launch(self):
        if self.fspath == None:
            self.write_config()
        self.db = fsdb.get_fs_db(self.fspath)
        self.init_pix()
        self.init_left_view()
        self.init_right_view()
        self.init_aircraft_model()
        self.init_panel_model()
        self.init_sound_model()
        self['PyFS_main'].show()
        
    def __getitem__(self, key):
        return self.xml.get_widget(key)

    def on_delete(self,widget,event):
        gtk.main_quit()

    def on_refresh(self,widget):
        self.db = fsdb.get_fs_db(self.fspath)
        self.init_aircraft_model()
        self.init_panel_model()
        self.init_sound_model()

    def on_quit(self,widget):
        self.on_delete(widget,None)

    def on_left_view_activate(self,widget,node,column):
        right_view = self['right_view']
        if node == (0,):
            right_view.set_model(None)
        elif node == (0,0):
            right_view.set_model(right_view.model[0])
        elif node == (0,1):
            right_view.set_model(right_view.model[1])
        elif node == (0,2):
            right_view.set_model(right_view.model[2])

    def on_right_view_activate(self,widget,node,column):
        print self.db[0][self['right_view'].model[0][node][1]][0]
    
    def connect(self):
        self.event_table = {'on_pyfs_delete':self.on_delete,
                            'on_menu_quit':self.on_quit,
                            'on_left_view_activate':self.on_left_view_activate,
                            'on_right_view_activate':self.on_right_view_activate,
                            'on_bar_refresh_clicked':self.on_refresh}
        self.xml.signal_autoconnect(self.event_table)

if (__name__ == "__main__"):
    theApp = PyFS_main()
    gtk.main()
